@@ -79,7 +79,7 @@ async def _(bot: Bot, event: Event, state: T_State):
         await plugin_manager.finish(message)
 
     if state["args"].command == "block":
-        if group_id and event.sender.role == "member":
+        if group_id and event.sender.role == "member" or not str(event.user_id) in bot.config.superusers:
             await plugin_manager.finish("权限不足")
 
         if state["args"].default:
@@ -112,7 +112,7 @@ async def _(bot: Bot, event: Event, state: T_State):
         await plugin_manager.finish(message)
 
     if state["args"].command == "unblock":
-        if group_id and event.sender.role == "member":
+        if group_id and event.sender.role == "member" or not str(event.user_id) in bot.config.superusers:
             await plugin_manager.finish("权限不足")
 
         if state["args"].default:
